netapp_ontap.models.security_certificate_sign API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.security_certificate_sign`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class SecurityCertificateSignSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the SecurityCertificateSign object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `expiry_time: str GET POST PATCH`

    Certificate expiration time, in ISO 8601 duration format or date and time format. The allowed expiration time range is between 1 day to 10 years.

    Example: P1DT2H3M4S or '2030-01-25T11:20:13Z'

  `hash_function: str GET POST PATCH`

    Hashing function

    Valid choices:

    - sha256
    - sha224
    - sha384
    - sha512
  `signing_request: str GET POST PATCH`

    Certificate signing request to be signed by the given certificate authority. Request should be in X509 PEM format.

    Example: